﻿// Photo Frame - Adobe Photoshop Script
// Description: a simple script 
// Requirements: Adobe Photoshop CS, or higher
// Version: 0.0.1, 12/Mar/2015
// Author: Anil Tejwani (anil@tejwani.com)
// Website: http://tejwani.com/
// ============================================================================
 
function setPreferences(){
	// user settings
	prefs.sourceDir         = '~';  // default browse location (default: '~')
	prefs.removeFileExtensions = true; // remove filename extensions for imported layers (default: true)
	prefs.savePrompt           = false; // display save prompt after import is complete (default: false)
	prefs.closeAfterSave       = true; // close import document after saving (default: false)
	prefs.importFileExtensions = '/\.(?:.png|.gif|.jpg|.bmp|.tif)$/i';
    prefs.outputQuality = 10; //init
    settingDialog(); // set
	return prefs;
}

// ***** No editing required below this line *****


try{
    // set preferences
    var prefs = new Object();
    prefs = setPreferences(prefs);
    // process
    main();    
    }
catch(e){
    alert("Something went wrong, sorry. (" + e.toString() + ")");
    }



///////////////////////////////////////////////////////////////////////////////
// main function
///////////////////////////////////////////////////////////////////////////////
function main() {
	// select source and destination folder
	sourceDir = Folder.selectDialog( 'Step2: Select the directory to IMPORT IMAGES from.', '~' );
	outDir = Folder.selectDialog( 'Step3: Select the directory to EXPORT FRAMED IMAGES to.', sourceDir.toString());
	
	// check if sourceDir do exists
	if (!sourceDir) {
		alert('Error!!! Source folder.('+sourceDir+') Not Selected', 'Script Stopped', true);
		return;
	}else if (!sourceDir.exists) {
		alert('Error!!! Source folder not found.', 'Script Stopped', true);
		return;
	}

    // check if sourceDir do exists
        if (!outDir) {
            alert('Error!!! Output folder.('+sourceDir+') Not Selected', 'Script Stopped', true);
            return;
        }else if (!outDir.exists) {
            alert('Error!!! Output folder not found.', 'Script Stopped', true);
            return;
        }
	
     if (outDir.toString() == sourceDir.toString()) {
         alert('Error!!! Output folder and Input Folder cant be same.', 'Script Stopped', true);
         return;
     }
 
	// add source folder to user settings
	prefs.sourceDir = sourceDir;
	prefs.outDir = outDir;
	
	var files = getFiles(prefs.sourceDir, prefs.importFileExtensions);
	if (files.length) {
		processFiles(files, prefs);
		revertFile();
	}else{
		alert('Error!!! No Images found to import from IMPORT folder('+sourceDir+')', 'No Files Found', false);
	}
	
}

function revertFile(){
	activeDocument.activeHistoryState = activeDocument.historyStates[0];
}

///////////////////////////////////////////////
// lets process all files found in the folder
///////////////////////////////////////////////
function processFiles(files, prefs){
	for(i=0; i < files.length; i++){
		processFile(files[i], prefs);
	}
}
function processFile(thisFile, prefs){
	var origDoc = activeDocument;
	var insertLayer = origDoc.activeLayer;
	var quality = 10;
	var doc = open(thisFile);
	// get document name (and remove file extension)
	var layerName = doc.name;
	if (prefs.removeFileExtensions) {
		layerName = layerName.replace(/(?:\.[^.]*$|$)/, '');
	}
	// rename layer; duplicate to new document
	var layer = doc.activeLayer;
	layer.name = layerName;
	layer.duplicate(origDoc, ElementPlacement.PLACEATBEGINNING);
	
	// close imported document
	doc.close(SaveOptions.DONOTSAVECHANGES);	

	// move current layer 
	origDoc.activeLayer.move(insertLayer, ElementPlacement.PLACEBEFORE);	
	
	// save
	SaveAsJPEG( prefs.outDir, layerName);
	
	// delete
	origDoc.activeLayer.remove();
    
    return;
}


///////////////////////////////////////////////////////////////////////////////
// getFiles - get all files within the specified source
// param string, folder path to pick files list from
// param string, list of extension to consider
///////////////////////////////////////////////////////////////////////////////
function getFiles(sourceFolder, extList) {
	
	// declare local variables
	var fileArray = new Array();

	// get all files in source folder
	var docs = sourceFolder.getFiles();
	var len = docs.length;
	for (var i = 0; i < len; i++) {
		var doc = docs[i];
		// only match files (not folders)
		if (doc instanceof File) {
			// store all recognized files into an array
			var docName = doc.name;
			if (docName.match(eval(extList))) {
				// exte
				fileArray.push(doc);
			}
		}
	}
	// return file array
	return fileArray;
}

///////////////////////////////////////////////////////////////////////////////
// Function: SaveAsJPEG
// Use: save the current document as a copy using JPEG options
// Input: a document must be active
// Params: folder, filename, extension
///////////////////////////////////////////////////////////////////////////////
function SaveAsJPEG( folder, fileName ) {
        var jpegOptions = new JPEGSaveOptions();
        jpegOptions.quality = prefs.outputQuality; 
        jpegOptions.embedColorProfile = true; 
        
        // are we using extensions on this save
        var jpegExtension = '.jpg';
		
        // third option is as a copy, set that to true 
        // so the activeDocument doesn't switch underneath the user
        activeDocument.saveAs( File( folder + '/' + fileName + jpegExtension ), jpegOptions, true );
}

function settingDialog() {

    #target estoolkit
    var win, windowResource;
     
    windowResource = "dialog {  orientation: 'column', alignChildren: ['fill', 'top'],  preferredSize:[450, 250], text: 'Settings',  margins:10, \
        \
        settingPanel: Group { \
            orientation: 'column',\
            st:   StaticText { text: 'Photoshop Script - Create Photoframes from PSD.' }, \
            st2: StaticText { text: 'Step1: select the OUTPUT QUALITY' }, \
            st3: StaticText { text: 'Step2: select the INPUT folder' }, \
            st4: StaticText { text: 'Step3: select the OUTPUT folder' }, \
            st5: StaticText { text: '**************************************************'  }, \
            st6: StaticText { text: '' }, \
            st7: StaticText { text: 'Step1: Select JPEG Output Quality (1:Low to 12:High)' }, \
            sl: Slider { minvalue: 1, maxvalue: 12, value: 12, size:[410,20] }, \
            quality: StaticText { text: '12', characters: 2} \
             applyButton: Button { text: 'Apply And Continue To Step2 (INPUT Folder Selection) »', properties:{name:'ok'}, size:[410,30] , weight:bold}, \
               \
        } \
        creditGroup: Group { orientation: 'row', alignChildren: 'right', \
        linkText: StaticText { text: 'www.tejwani.com/photoshop-scripting' , alignment:['right', 'center']}, \
            } \
    }"
     
    win = new Window(windowResource);

    // listen and update text box
    win.settingPanel.sl.onChange = function() {
        win.settingPanel.quality.text = Math.round(this.value);
    }

    // apply button
    win.settingPanel.applyButton.onClick = function() {
        prefs.outputQuality = win.settingPanel.quality.text;
        return win.close();
    };

    win.show();    
    
}